# $name Collection

[![Icestudio](https://img.shields.io/badge/collection-icestudio-blue.svg)](https://github.com/FPGAwars/icestudio)
![Version](https://img.shields.io/badge/version-v$version-orange.svg)

$description.

## Install

* Download the collection$links
* Install the collection: *Tools > Collections > Add*
* Load the collection: *Select > Collection*

$blocks
$examples
$languages
$authors
$contributors
## License

Licensed under [$license](https://opensource.org/licenses/$license).
